"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.foundationGenerator = void 0;
const tslib_1 = require("tslib");
const utils_1 = require("../../utils");
const component_1 = require("../actions/component");
const messages_1 = require("../messages");
const validators_1 = require("../validators");
/**
 * Foundation Base Component Set Generator
 */
exports.foundationGenerator = {
    description: (0, messages_1.generatorDescription)('Re-generate the foundation-ui base components.'),
    prompts(inquirer, prevAns = {}) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            /**
             * TODO: Find out what these are for since they don't seem to be used
             */
            const fastAPI = require('../../fast-components.api.json');
            const fastExports = fastAPI && fastAPI.members[0].members.map((m) => m.name);
            const foundationAPI = require('../../fast-foundation.api.json');
            const foundationExports = foundationAPI && foundationAPI.members[0].members.map((m) => m.name);
            const foundationComponentExports = foundationAPI &&
                foundationAPI.members[0].members
                    .filter((m) => m.kind === 'Class' &&
                    m.excerptTokens[1] &&
                    m.excerptTokens[1].text.match(/FoundationElement|FormAssociated/))
                    .map((m) => m.name);
            const defaultHostDirectives = [
                'checkbox',
                'divider',
                'flipper',
                'radio',
                'radio-group',
                'skeleton',
                'tab',
                'tab-panel',
                'tabs',
            ];
            /**
             * Which options to de-select by default when presenting the menu
             */
            const defaultExclusions = [
                'accordion-item',
                'breadcrumb-item',
                'color',
                'data-grid',
                'horizontal-scroll',
                'listbox-option',
                'menu-item',
                'progress-ring',
                'slider-label',
                'styles',
                'tree-item',
                'utilities',
            ];
            const baseComponentsDirectories = (0, utils_1.getBaseComponentsDirectories)();
            const baseComponentsCheckboxChoices = (0, utils_1.mapToCheckboxChoices)(baseComponentsDirectories);
            const designSystemsDirectories = (0, utils_1.getDesignSystemsDirectories)();
            const { components, designSystemChoices, force } = yield inquirer.prompt([
                {
                    type: 'checkbox',
                    message: 'Which components should this include?',
                    name: 'components',
                    choices: baseComponentsCheckboxChoices,
                    default: (0, utils_1.mapToNames)(baseComponentsDirectories).filter((name) => !defaultExclusions.includes(name)),
                    validate: validators_1.atLeastOne,
                },
                {
                    type: 'checkbox',
                    message: 'Which design systems should this be included in?',
                    name: 'designSystemChoices',
                    choices: (0, utils_1.mapToCheckboxChoices)(designSystemsDirectories),
                    default: (0, utils_1.mapToNames)(designSystemsDirectories),
                },
                {
                    type: 'confirm',
                    message: 'Overwrite existing files?',
                    name: 'force',
                    default: true,
                },
            ]);
            return {
                components,
                designSystemChoices,
                force,
            };
        });
    },
    actions: (answers) => (0, component_1.getAddComponentActions)(Object.assign(Object.assign({}, answers), { baseComponent: true })),
};
