import inquirer from 'inquirer';
import { ActionConfig, NodePlopAPI } from 'node-plop';
/**
 * Remote seed sources are git repos that we clone during the cli workspace and app creation flows. Local seed
 * sources exist within the filesystem itself. These will be useful for testing new seeds before making them repos.
 */
export declare enum SeedSource {
    local = "local",
    remote = "remote"
}
export interface DirectoryActionConfig extends ActionConfig {
    get directory(): string;
}
export type OptionsValues = null | string | number;
export type GitOptions = Record<string, OptionsValues>;
export type Configure = (answers: inquirer.Answers, config: DirectoryActionConfig, plop: NodePlopAPI) => Promise<void>;
export type Prompts = (inquirer: inquirer.Inquirer, answers?: inquirer.Answers) => Promise<inquirer.Answers>;
type BaseSeedSource = {
    name: string;
    about: string;
    tags: string[];
    configure: Configure;
    /**
     * Additional prompts asked after selection
     */
    prompts?: Prompts;
};
export type LocalSeedSource = BaseSeedSource & {
    type: SeedSource & SeedSource.local;
    baseDir?: string;
};
export type RemoteSeedSource = BaseSeedSource & {
    type: SeedSource & SeedSource.remote;
    vcsUrl: string;
    vcsOperation: string;
    vcsRemote: string;
    remoteUser: string;
    remoteRepo: string;
    remoteBranch: string;
    remoteName: string;
    gitOptions?: GitOptions;
};
export type SeedSources = LocalSeedSource | RemoteSeedSource;
export declare enum SeedDelivery {
    download = "Download",
    clone = "Clone"
}
export {};
//# sourceMappingURL=types.d.ts.map